# gosei

Make a collage from two photos.

# Installation

```bash
pip install gosei
```

# Run

```
gosei -a /path/to/first/image -b /path/to/second/image -o /save/path
```

# Limitations

- Only works with vertical photos in same size now
